from setuptools import setup

setup(
    author='djfurman',
    author_email='djfurman@gmail.com',
    name='alb-response',
    version='0.1.0',
    packages=['alb_response'],
    license='BSD-3-Clause',
    long_description=open('ReadMe.md').read(),
    long_description_content_type='text/markdown',
)
